==> iTop-3.0.3-10998.zip: web/dictionaries/ui/layouts/activity-panel/zh_cn.dictionary.itop.activity-panel.php <==
<?php
/**
 * Copyright (C) 2013-2021 Combodo SARL
 *
 * This file is part of iTop.
 *
 * iTop is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * iTop is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 */
// Activity panel
Dict::Add('ZH CN', 'Chinese', '简体中文', array(
	'UI:Layout:ActivityPanel:SizeToggler:Expand:Tooltip' => '展开',
	'UI:Layout:ActivityPanel:SizeToggler:Reduce:Tooltip' => '减少',
	'UI:Layout:ActivityPanel:DisplayToggler:Close:Tooltip' => '关闭',
	'UI:Layout:ActivityPanel:LoadMoreEntries:Tooltip' => '加载更多',
	'UI:Layout:ActivityPanel:LoadAllEntries:Tooltip' => '加载全部',

	// Tabs
	'UI:Layout:ActivityPanel:Tab:Activity:Title' => '活动',
	'UI:Layout:ActivityPanel:Tab:Log:DraftIndicator:Tooltip' => '草稿',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Title' => '日志',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Tooltip' => '显示/隐藏 日志',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Menu:Hint' => '请选择要显示的日志',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Title' => '状态变化',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Tooltip' => '显示 / 隐藏 状态变化',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Title' => '编辑',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Tooltip' => '显示 / 隐藏 字段编辑',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:OpenAll:Tooltip' => '全部打开',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:CloseAll:Tooltip' => '全部关闭',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:AuthorsCount:Tooltip' => 'Number of persons interacting in the visible entries~~',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:MessagesCount:Tooltip' => 'Number of messages in the visible log(s)~~',

	// Compose button
	'UI:Layout:ActivityPanel:ComposeButton:Tooltip' => '撰写新的条目',

	// Case log entry
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Title' => '保存多个条目',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Explanation' => '点击 "保存" 按钮, 将会一次性提交所有已编辑的日志.',

	// Notification entry
	'UI:Layout:ActivityPanel:NotificationEntry:MessageLink:Tooltip' => '点击打开通知栏以获得更多信息',

	// Placeholder
	'UI:Layout:ActivityPanel:NoEntry:Placeholder:Hint' => '很平静, 暂无任何活动',

	// Closed cover
	'UI:Layout:ActivityPanel:ClosedCover:Title' => '活动面板',
	'UI:Layout:ActivityPanel:ClosedCover:Tooltip' => '点击打开活动面板',
));

==> iTop-3.1.0-2-11973.zip: web/dictionaries/ui/layouts/activity-panel/zh_cn.dictionary.itop.activity-panel.php <==
<?php
/**
 * Copyright (C) 2013-2023 Combodo SARL
 *
 * This file is part of iTop.
 *
 * iTop is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * iTop is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 */
// Activity panel
Dict::Add('ZH CN', 'Chinese', '简体中文', array(
	'UI:Layout:ActivityPanel:SizeToggler:Expand:Tooltip' => '展开',
	'UI:Layout:ActivityPanel:SizeToggler:Reduce:Tooltip' => '减少',
	'UI:Layout:ActivityPanel:DisplayToggler:Close:Tooltip' => '关闭',
	'UI:Layout:ActivityPanel:LoadMoreEntries:Tooltip' => '加载更多',
	'UI:Layout:ActivityPanel:LoadAllEntries:Tooltip' => '加载全部',

	// Tabs
	'UI:Layout:ActivityPanel:Tab:Activity:Title' => '活动',
	'UI:Layout:ActivityPanel:Tab:Log:DraftIndicator:Tooltip' => '草稿',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Title' => '日志',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Tooltip' => '显示/隐藏 日志',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Menu:Hint' => '请选择要显示的日志',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Title' => '状态变化',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Tooltip' => '显示/隐藏 状态变化',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Title' => '编辑',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Tooltip' => '显示/隐藏 字段编辑',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:OpenAll:Tooltip' => '全部打开',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:CloseAll:Tooltip' => '全部关闭',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:AuthorsCount:Tooltip' => '正在查看此条目的人数',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:MessagesCount:Tooltip' => '此日志的消息数',

	// Compose button
	'UI:Layout:ActivityPanel:ComposeButton:Tooltip' => '撰写新的条目',

	// Case log entry
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Title' => '保存多个条目',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Explanation' => '点击 "保存" 按钮, 将会一次性提交所有已编辑的日志.',

	// Notification entry
	'UI:Layout:ActivityPanel:NotificationEntry:MessageLink:Tooltip' => '点击打开通知栏以获得更多信息',

	// Placeholder
	'UI:Layout:ActivityPanel:NoEntry:Placeholder:Hint' => '暂无任何活动',

	// Closed cover
	'UI:Layout:ActivityPanel:ClosedCover:Title' => '活动面板',
	'UI:Layout:ActivityPanel:ClosedCover:Tooltip' => '点击打开活动面板',
));
